# Literate Programming Tools: *Literacy*
Literacy is a library made for [Literate Programming](https://en.wikipedia.org/wiki/Literate_programming) or [Literate Computing](http://blog.fperez.org/2013/04/literate-computing-and-computational.html) using Python Jupyter Notebook files.
